==> igniteui-react-charts-18.2.0-beta.0.tgz: package/esm5/lib/CategoryChartToolbarProvider.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { DomainChartToolbarProvider } from "./DomainChartToolbarProvider";
import { markType } from "igniteui-react-core";
/**
 * @hidden
 */
var CategoryChartToolbarProvider = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(CategoryChartToolbarProvider, _super);
    function CategoryChartToolbarProvider() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.v = null;
        return _this;
    }
    CategoryChartToolbarProvider.prototype.d = function (a, b) {
        var c = a;
        switch (b.name) {
            case "ShowGridlines":
                {
                    var d = b;
                    d.isChecked = c.ab9 != null;
                }
                break;
        }
    };
    CategoryChartToolbarProvider.prototype.r = function (a, b, c, d) {
        var e = a;
        switch (b) {
            case "XAxisMajorStroke":
                this.e("ShowGridlines", 2, a.ab9 != null);
                break;
        }
    };
    CategoryChartToolbarProvider.prototype.i = function (a, b) {
        var c = a;
        if (this.b(b, "ShowGridlines")) {
            if (c.ab9 == null) {
                if (this.v != null) {
                    c.ab9 = this.v;
                }
                else {
                    c.ab9 = c.dataChart.xv;
                }
            }
        }
        else {
            if (c.ab9 != null) {
                this.v = c.ab9;
                c.ab9 = null;
            }
        }
    };
    CategoryChartToolbarProvider.$t = markType(CategoryChartToolbarProvider, 'CategoryChartToolbarProvider', DomainChartToolbarProvider.$);
    return CategoryChartToolbarProvider;
}(DomainChartToolbarProvider));
export { CategoryChartToolbarProvider };

==> igniteui-react-charts-18.3.2-beta.0.tgz: package/esm5/lib/CategoryChartToolbarProvider.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { DomainChartToolbarProvider } from "./DomainChartToolbarProvider";
import { markType } from "igniteui-react-core";
/**
 * @hidden
 */
var CategoryChartToolbarProvider = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(CategoryChartToolbarProvider, _super);
    function CategoryChartToolbarProvider() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.y = null;
        return _this;
    }
    CategoryChartToolbarProvider.prototype.e = function (a, b) {
        var c = a;
        switch (b.name) {
            case "ShowGridlines":
                {
                    var d = b;
                    d.isChecked = c.ace != null;
                }
                break;
        }
    };
    CategoryChartToolbarProvider.prototype.u = function (a, b, c, d) {
        var e = a;
        switch (b) {
            case "XAxisMajorStroke":
                this.f("ShowGridlines", 2, a.ace != null);
                break;
        }
    };
    CategoryChartToolbarProvider.prototype.k = function (a, b) {
        var c = a;
        if (this.c(b, "ShowGridlines")) {
            if (c.ace == null) {
                if (this.y != null) {
                    c.ace = this.y;
                }
                else {
                    c.ace = c.dataChart.x4;
                }
            }
        }
        else {
            if (c.ace != null) {
                this.y = c.ace;
                c.ace = null;
            }
        }
    };
    CategoryChartToolbarProvider.$t = markType(CategoryChartToolbarProvider, 'CategoryChartToolbarProvider', DomainChartToolbarProvider.$);
    return CategoryChartToolbarProvider;
}(DomainChartToolbarProvider));
export { CategoryChartToolbarProvider };
